window.dhx_globalImgPath = "dhtmlx_std/imgs/";
var dp, isSchedularDragEvent;

function doInitSchedulerDataProcessor(action, schedulerDiv) {
	dp = new dataProcessor(action);
	dp.init(schedulerDiv);
	dp.defineAction("onSchedulerInsertError", onSchedulerInsertErrorAction);
	dp.defineAction("onSchedulerUpdateError", onSchedulerUpdateErrorAction);
	dp.setTransactionMode("POST");
	dp.enableDataNames(true);
}

function onSchedulerInsertErrorAction(node) {
	var message = node.firstChild.data;
	if (message != null && message.length > 0) {
		alert(message);
	}

	var eventId = node.getAttribute("sid");
	scheduler.deleteEvent(eventId);
}

function onSchedulerUpdateErrorAction(node) {
	var data = node.firstChild.data;
	if (data != null && data.length > 0) {
		tokens = data.split('|');
		alert(tokens[0]);

		var startDate = new Date(tokens[1]);
		var endDate = new Date(tokens[2]);

		var eventId = node.getAttribute("sid");
		setEventEndDate(eventId, endDate);
		setEventStartDate(eventId, startDate);
	}
}

function initSchedular(appointmentType) {
	var step = 15;
	var format = scheduler.date.date_to_str("%h:%i %A");
	scheduler.config.hour_size_px = (60 / step) * 21;
	scheduler.templates.hour_scale = function(date) {
		html = "";
		for ( var i = 0; i < 60 / step; i++) {
			html += "<div style='height:21px;line-height:21px;'>"
					+ format(date) + "</div>";
			date = scheduler.date.add(date, step, "minute");
		}
		return html;
	}

	// scheduler.config.show_loading = true;
	scheduler.locale.labels.unit_tab = "Doctors"
	scheduler.locale.labels.section_custom = "Select the Doctor";

	scheduler.config.collision_limit = 5;
	scheduler.config.details_on_create = true;
	scheduler.config.details_on_dblclick = true;
	scheduler.config.multi_day = true;
	scheduler.config.xml_date = "%d-%m-%Y %h:%i %A";
	scheduler.config.hour_date = "%h:%i %A";
	scheduler.config.first_hour = 8;
	scheduler.config.last_hour = 20;
	scheduler.config.time_step = 15;

	var loader = dhtmlxAjax.postSync("GetDoctors.do");
	var doctors = getDoctorList(loader);

	initCustomEditor(appointmentType, doctors);
	scheduler.templates.event_text = function(start, end, event) {
		return "<b>Reg. Id:&nbsp;</b>" + event.regId
				+ "<br><b>Title:&nbsp;</b>" + event.text;
	}

	if (doctors.length > 4) {
		scheduler.createUnitsView( {
			name : "unit",
			property : "doctorId",
			list : doctors,
			size : 4,
			step : 2
		});
	} else {
		scheduler.createUnitsView("unit", "doctorId", doctors);
	}

	if (appointmentType == "singlePatientAppointments") {
		scheduler.init('appScheduler', null, "day");
	} else {
		scheduler.init('appScheduler', null, "unit");
	}

	var url;
	if (appointmentType == "singlePatientAppointments") {
		var patientId = document.getElementById("patientId").value;
		url = "ShowPatientsAppointments.do?patientId=" + patientId;
	} else {
		var doctorId = document.getElementById("doctorId").value;
		url = "ShowAllAppointments.do?doctorId=" + doctorId;
	}
	scheduler.load(url);
}

function autoAppointmentPopup() {
	var eventId = scheduler.uid();
	scheduler._loading = true;

	var startDate = new Date();
	var endDate = new Date();

	scheduler.addEvent(startDate, endDate, scheduler.locale.labels.new_event,
			eventId, {
				resources : scheduler.locale.labels.new_resources,
				organizer : scheduler.locale.labels.new_organizer,
				timeoffset : (new Date()).getTimezoneOffset()
			});
	scheduler.callEvent("onEventCreated", [ eventId,
			scheduler.getEvent(eventId) ]);
	scheduler._loading = false;
	scheduler._new_event = new Date();
	scheduler.showLightbox(eventId);
}

function getDoctorList(loader) {
	var doctorList = [];
	var xmlDoc = loader.xmlDoc.responseXML;
	if (xmlDoc != null) {
		var doctors = xmlDoc.getElementsByTagName("doctor");
		for (i = 0; i < doctors.length; i++) {
			var id = doctors[i].getAttribute("id");
			var name = doctors[i].firstChild.nodeValue;
			doctorList.push( {
				key : id,
				label : name
			});
		}
	}
	return doctorList;
}

function initCustomEditor(appointmentType, doctors) {

	scheduler.form_blocks["customEditor"] = {
		render : function(sns) {
			if (appointmentType == "singlePatientAppointments") {
				var regId = document.getElementById("regId").value;
				return "<div class='dhx_cal_ltext' style='height:100px;'>"
						+ "<b>Registration Id:&nbsp;</b><label>"
						+ regId
						+ "</label>&nbsp;&nbsp;&nbsp;"
						+ "<b>* Title:&nbsp;</b><input type='text' size='30'><br/>"
						+ "<b>Details:&nbsp;</b><textarea></textarea></div>";
			} else {
				return "<div class='dhx_cal_ltext' style='height:100px;'>"
						+ "<b>Registration Id:&nbsp;</b><input type='text' size='10'>&nbsp;&nbsp;&nbsp;"
						+ "<b>* Title:&nbsp;</b><input type='text' size='30'><br/>"
						+ "<b>Details:&nbsp;</b><textarea></textarea></div>";
			}
		},
		set_value : function(node, value, event) {
			node.childNodes[4].value = value || "";
			if (appointmentType == "singlePatientAppointments") {
				var regId = document.getElementById("regId").value;
				node.childNodes[1].value = event.regId || regId;
			} else {
				node.childNodes[1].value = event.regId || "";
			}
			node.childNodes[7].value = event.details || "";
		},
		get_value : function(node, event) {
			event.regId = node.childNodes[1].value;
			event.details = node.childNodes[7].value;
			return node.childNodes[4].value;
		},
		focus : function(node) {
			var a = node.childNodes[4];
			a.select();
			a.focus();
		}
	}

	scheduler.config.lightbox.sections = [ {
		name : "description",
		height : 200,
		map_to : "text",
		type : "customEditor",
		focus : true
	}, {
		name : "custom",
		height : 23,
		type : "select",
		options : doctors,
		map_to : "doctorId"
	}, {
		name : "time",
		height : 72,
		type : "calendar_time",
		map_to : "auto"
	} ]

}

function show_minical() {
	if (scheduler.isCalendarVisible()) {
		scheduler.destroyCalendar();
	} else {
		scheduler.renderCalendar( {
			position : "dhx_minical_icon",
			date : scheduler._date,
			navigation : true,
			handler : function(date, calendar) {
				scheduler.setCurrentView(date);
				scheduler.destroyCalendar()
			}
		});
	}
}
